@@ -61,20 +61,24 @@ class CentralReachRequestsCore:
         except json.decoder.JSONDecodeError:
             return False
 
-    def check_response(self, response, mandatory_json=False, exc_message='') -> None:
+    def check_response(self, response,
+                       mandatory_json: bool = False,
+                       exc_message: str = '',
+                       re_authorize: bool = True) -> None:
         """
         This method check response and raise exception 'BadRequest' or 'ScheduledMaintenance' with exc_message,
         If status code is 401 (unauthorized) then it will try login again
         :param response: response from request
         :param mandatory_json: bool, if True - it will check is response contain json data
         :param exc_message: text message which will be raise if response wrong
+        :param re_authorize: bool, if True then it will try login again if status code is 401
         """
         if self.__is_scheduled_maintenance(response):
             print(exc_message, 'Error')
             print("'Central Reach' site is currently unavailable due to scheduled maintenance", 'Error')
             raise ScheduledMaintenance
 
-        elif response.status_code == 401:
+        elif re_authorize and response.status_code == 401:
             self._login_to_central_reach(self.__login, self.__password)
             raise BadRequest(f"{exc_message}Status Code: {response.status_code} (Unauthorized request), "
                              f"Json content: {response.json()}, Headers: {response.headers}")
@@ -92,12 +96,32 @@ class CentralReachRequestsCore:
     def _login_to_central_reach(self, login: str, password: str) -> None:
         central_reach_core = CentralReachCore(login, password)
         central_reach_core.login_to_site()
-        time.sleep(10)
 
-        for name, value in central_reach_core.browser.get_cookies(as_dict=True).items():
-            self.session.cookies.set(name, value)
+        # Check authorisation
+        timeout_time = datetime.datetime.now() + datetime.timedelta(seconds=30)
+        while datetime.datetime.now() < timeout_time:
+            try:
+                # Set cookies
+                for name, value in central_reach_core.browser.get_cookies(as_dict=True).items():
+                    self.session.cookies.set(name, value)
+                # Check authorization
+                self.__insurance_eligibility_status()
+                break
+            except BadRequest:
+                time.sleep(1)
+                continue
+        else:
+            raise BadRequest("Session is unauthorized after login to Central Reach")
         central_reach_core.browser.close_browser()
 
+    def __insurance_eligibility_status(self) -> None:
+        header = {'referer': 'https://members.centralreach.com/'}
+        url = 'https://members.centralreach.com/crxapi/system/dictionary/InsuranceEligibilityStatus'
+        response = self.session.get(url, headers=self._get_headers(is_json=True, add_headers=header))
+
+        exception_message = f"Problems with insurance eligibility request."
+        self.check_response(response, mandatory_json=True, exc_message=exception_message, re_authorize=False)
+
     @retry_if_bad_request
     def _get_filters(self):
         payload = {
